@@ -15,7 +15,6 @@
 package local
 
 import (
-	"errors"
 	"fmt"
 )
 
@@ -30,11 +29,6 @@ var notAllowedEnvVarOverwrites = []string{
 	"CI_WORKSPACE",
 }
 
-var (
-	ErrUnsupportedStepType   = errors.New("unsupported step type")
-	ErrWorkflowStateNotFound = errors.New("workflow state not found")
-)
-
 const netrcFile = `
 machine %s
 login %s
