@@ -16,6 +16,7 @@ package bitbucketdatacenter
 
 import (
 	"context"
+	"errors"
 	"fmt"
 	"net/http"
 	"net/url"
@@ -33,6 +34,7 @@ import (
 	forge_types "go.woodpecker-ci.org/woodpecker/v3/server/forge/types"
 	"go.woodpecker-ci.org/woodpecker/v3/server/model"
 	"go.woodpecker-ci.org/woodpecker/v3/server/store"
+	"go.woodpecker-ci.org/woodpecker/v3/shared/httputil"
 )
 
 const (
@@ -202,6 +204,10 @@ func (c *client) Repo(ctx context.Context, u *model.User, rID model.ForgeRemoteI
 		return nil, fmt.Errorf("unable to fetch default branch: %w", err)
 	}
 
+	if b.DisplayID == "" {
+		return nil, errors.New("default branch setting does not exist")
+	}
+
 	perms := &model.Perm{Pull: true, Push: true}
 	_, _, err = bc.Projects.ListWebhooks(ctx, repo.Project.Key, repo.Slug, &bb.ListOptions{})
 	if err == nil {
@@ -493,7 +499,7 @@ func (c *client) Deactivate(ctx context.Context, u *model.User, r *model.Repo, l
 }
 
 func (c *client) Hook(ctx context.Context, r *http.Request) (*model.Repo, *model.Pipeline, error) {
-	hook, err := parseHook(r, c.url)
+	hook, currCommit, prevCommit, err := parseHook(r, c.url)
 	if err != nil {
 		return nil, nil, fmt.Errorf("unable to parse hook: %w", err)
 	}
@@ -512,7 +518,7 @@ func (c *client) Hook(ctx context.Context, r *http.Request) (*model.Repo, *model
 
 	switch e := hook.Event.(type) {
 	case *bb.RepositoryPushEvent:
-		pipe, err = c.updatePipelineFromCommit(ctx, user, repo, hook.Pipeline)
+		pipe, err = c.updatePipelineFromCommits(ctx, user, repo, hook.Pipeline, currCommit, prevCommit)
 	case *bb.PullRequestEvent:
 		pipe, err = c.updatePipelineFromPullRequest(ctx, user, repo, hook.Pipeline, e.PullRequest.ID)
 	}
@@ -552,7 +558,7 @@ func (c *client) getUserAndRepo(ctx context.Context, r *model.Repo) (*model.User
 	return user, repo, nil
 }
 
-func (c *client) updatePipelineFromCommit(ctx context.Context, u *model.User, r *model.Repo, p *model.Pipeline) (*model.Pipeline, error) {
+func (c *client) updatePipelineFromCommits(ctx context.Context, u *model.User, r *model.Repo, p *model.Pipeline, currCommit, prevCommit string) (*model.Pipeline, error) {
 	if p == nil {
 		return nil, nil
 	}
@@ -568,9 +574,15 @@ func (c *client) updatePipelineFromCommit(ctx context.Context, u *model.User, r
 	}
 	p.Message = commit.Message
 
-	opts := &bb.ListOptions{}
+	opts := &bb.CompareChangesOptions{}
+	if currCommit != "" {
+		opts.From = currCommit
+	}
+	if prevCommit != "" {
+		opts.To = prevCommit
+	}
 	for {
-		changes, resp, err := bc.Projects.ListChanges(ctx, r.Owner, r.Name, p.Commit, opts)
+		changes, resp, err := bc.Projects.CompareChanges(ctx, r.Owner, r.Name, opts)
 		if err != nil {
 			return nil, fmt.Errorf("unable to list commit changes: %w", err)
 		}
@@ -763,5 +775,6 @@ func (c *client) newClient(ctx context.Context, u *model.User) (*bb.Client, erro
 		AccessToken: u.AccessToken,
 	}
 	client := config.Client(ctx, t)
+	client = httputil.WrapClient(client, "forge-bitbucketdatacenter")
 	return bb.NewClient(c.urlAPI, client)
 }
